GenDelegate v1.0.0 GenDelegate
This module provides delegation abilities to a developer in order to expose
local functions from within a GenServer.
Summary
Macros
Allows delegation of an internal function to a GenServer interface
Macros
Allows delegation of an internal function to a GenServer interface.
Delegation should be used when binding a function needed locally against a function which is also needed remotely.
Options
:alias- a name to refer to the state as, instead ofstate.:type- the type of delegate this is. Any of:cast,:calland:info.
Examples
gen_delegate function(var_one, state), type: :cast
gen_delegate function(var_one, state), type: [ :call, :cast ]
gen_delegate function(var_one, names), type: :info, alias: :names